@@ -850,12 +850,13 @@ diff_2_files (struct comparison *cmp)
 	/* Scan both files, a buffer at a time, looking for a difference.  */
 	{
 	  /* Allocate same-sized buffers for both files.  */
+	  size_t lcm_max = PTRDIFF_MAX - 1;
 	  size_t buffer_size =
 	    buffer_lcm (sizeof (word),
 			buffer_lcm (STAT_BLOCKSIZE (cmp->file[0].stat),
 				    STAT_BLOCKSIZE (cmp->file[1].stat),
-				    PTRDIFF_MAX - 1),
-			PTRDIFF_MAX - 1);
+				    lcm_max),
+			lcm_max);
 	  for (f = 0; f < 2; f++)
 	    cmp->file[f].buffer = xrealloc (cmp->file[f].buffer, buffer_size);
 
